Pydenticon documentation
========================

.. image:: images/pydenticon.png
.. image:: images/pydenticon_inverted.png

Pydenticon is a small utility library that can be used for deterministically
generating identicons based on the hash of provided data.

The implementation is a port of the Sigil identicon implementation from:

* https://github.com/cupcake/sigil/

Support
-------

In case of problems with the library, please do not hestitate to contact the
author at **pydenticon (at) majic.rs**. The library itself is hosted on Github,
and on author's own websites:

* https://github.com/azaghal/pydenticon
* https://code.majic.rs/pydenticon
* https://projects.majic.rs/pydenticon

Contents:

.. toctree::
   :maxdepth: 2

   about
   installation
   usage
   algorithm
   privacy
   apireference
   testing
   releasenotes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

